import 'package:educational_audioplayer/ui/common_player.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:share/share.dart';

import '../player.dart';
import '../util/constants.dart';

_BottomPlayerState _playerState;

class BottomPlayer extends CommonPlayer {
  BottomPlayer(
      {String imageUrl:
          "https://ia801408.us.archive.org/34/items/speaker_202002/speaker.png"})
      : super(imageUrl: imageUrl);
  play(List<Audio> audios, int index,
      {Function setLastAudioMethodLocal, String image}) {
    if (currentAudios.length > 0 &&
        audios[index].url != currentAudios[_playerState.getAudioIndex()].url) {
      _playerState.stop();

      _playerState.startPlayList(audios, index,
          setLastAudioMethodLocal: setLastAudioMethodLocal, image: image);
    }
  }

  show() {
    _playerState.show();
  }

  @override
  _BottomPlayerState createState() {
    _playerState = _BottomPlayerState();
    return _playerState;
  }
}

class _BottomPlayerState extends CommonPlayerState {
  bool isHidden = true;

  hide() {
    setState(() {
      isHidden = true;
    });
  }

  show() {
    setState(() {
      isHidden = false;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Visibility(
      visible: !isHidden,
      maintainState: true,
      child: Container(
          color: Theme.of(context).highlightColor,
          padding: EdgeInsets.only(left: playerInset, right: playerInset),
          child: Wrap(children: [
            Column(
              children: <Widget>[
                Row(
                    mainAxisAlignment: MainAxisAlignment.spaceBetween,
                    children: <Widget>[
                      IconButton(
                          icon: Icon(
                            Icons.share,
                            size: closeIconSize,
                          ),
                          onPressed: () {
                            Share.share(
                                '${currentAudios[getAudioIndex()].chapterName}\n\n${currentAudios[getAudioIndex()].audioName}\n\n${currentAudios[getAudioIndex()].audioDescription}\n\n${currentAudios[getAudioIndex()].authorName}\n\n${currentAudios[getAudioIndex()].url}');
                          }),
                      Expanded(
                        child: Text(
                          currentAudios[getAudioIndex()].audioName,
                          textAlign: TextAlign.center,
                          style: TextStyle(fontSize: audioNameSize),
                        ),
                      ),
                      IconButton(
                          icon: Icon(
                            Icons.close,
                            size: closeIconSize,
                          ),
                          onPressed: () {
                            stop();
                            hide();
                          })
                    ]),
                Text(
                  currentAudios[getAudioIndex()].chapterName,
                  textAlign: TextAlign.center,
                  style: TextStyle(fontSize: chapterNameSize),
                ),
                Text(
                  currentAudios[getAudioIndex()].authorName,
                  textAlign: TextAlign.center,
                  style: TextStyle(fontSize: lecturerNameSize),
                ),
                Column(
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.center,
                      children: <Widget>[
                        Text(getSliderPositionText(),
                            style: TextStyle(fontSize: timeSize)),
                        Expanded(
                            child: CupertinoSlider(
                          value: getSliderSeeking() ?? getSliderValue(),
                          onChangeEnd: (val) {
                            onSliderChangeEnd(val);
                          },
                          onChanged: (val) {
                            onSliderChanged(val);
                          },
                        )),
                        Text(getSliderDurationText(),
                            textAlign: TextAlign.right,
                            style: TextStyle(fontSize: timeSize))
                      ],
                    ),
                  ],
                ),
                Row(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    Expanded(
                      flex: 5,
                      child: Container(),
                    ),
                    IconButton(
                        onPressed: () {
                          playPrevious();
                        },
                        iconSize: iconSize,
                        padding: EdgeInsets.only(
                            left: 0,
                            right: 0,
                            bottom: defaultPadding,
                            top: defaultPadding),
                        icon: Icon(Icons.skip_previous),
                        color: Theme.of(context).accentColor),
                    Expanded(
                      child: Container(),
                    ),
                    IconButton(
                        onPressed: () {
                          addSecondsToPosition(-10);
                        },
                        iconSize: iconSize,
                        padding: EdgeInsets.only(
                            left: 0,
                            right: 0,
                            bottom: defaultPadding,
                            top: defaultPadding),
                        icon: Icon(Icons.replay_10),
                        color: Theme.of(context).accentColor),
                    Expanded(
                      child: Container(),
                    ),
                    IconButton(
                        onPressed: onPlayPauseButtonPressed,
                        iconSize: iconSize,
                        padding: EdgeInsets.only(
                            left: 0,
                            right: 0,
                            bottom: defaultPadding,
                            top: defaultPadding),
                        icon: getPlayPauseButton(),
                        color: Theme.of(context).accentColor),
                    Expanded(
                      child: Container(),
                    ),
                    IconButton(
                        onPressed: () {
                          addSecondsToPosition(10);
                        },
                        iconSize: iconSize,
                        padding: EdgeInsets.only(
                            left: 0,
                            right: 0,
                            bottom: defaultPadding,
                            top: defaultPadding),
                        icon: Icon(Icons.forward_10),
                        color: Theme.of(context).accentColor),
                    Expanded(
                      child: Container(),
                    ),
                    IconButton(
                        onPressed: () {
                          playNext();
                        },
                        iconSize: iconSize,
                        padding: EdgeInsets.only(
                            left: 0,
                            right: 0,
                            bottom: defaultPadding,
                            top: defaultPadding),
                        icon: Icon(Icons.skip_next),
                        color: Theme.of(context).accentColor),
                    Expanded(
                      flex: 5,
                      child: Container(),
                    ),
                  ],
                ),
              ],
            ),
          ])),
    );
  }
}
